Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FromContext ¶
FromContext extracts the trace ID from context, or returns "".
func HTTPMiddleware ¶
HTTPMiddleware extracts or generates a trace ID from the X-Trace-Id header and injects it into the request context.
func NewContext ¶
NewContext returns a context with a new trace ID.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.